==> ann-0.3.tar.gz: ann-0.3/lib/ann_sink_log.cpp <==
/***************************************************************************
                          ann_sink_log.cpp  -  description
                             -------------------
    begin                : nie maj 4 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <ann_sink_log.h>

  //                     //
 // class ANN::Sink_log //
//                     //

ANN::Sink_log::~Sink_log()
{
}

bool
ANN::Sink_log::prepare(Size lengths, Size sizes, const char *label_in_,
                       const char *label_des_out_)
{
  set_labels(label_in_,label_des_out_);
  return true;
}

bool
ANN::Sink_log::feed(size_t which_, const Loc &where_, const Term &in,
                    const Term *des_out)
{
  log->log(in,label_in.label(),which_,&where_);
  if (des_out) log->log(*des_out,label_des_out.label(),which_,&where_);
  return true;
}

bool
ANN::Sink_log::update()
{
  return true;
}

==> ann-0.4.tar.gz: ann-0.4/lib/ann_sink_log.cpp <==
/***************************************************************************
                          ann_sink_log.cpp  -  description
                             -------------------
    begin                : nie maj 4 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <ann_sink_log.h>

  //                     //
 // class ANN::Sink_log //
//                     //

ANN::Sink_log::~Sink_log()
{
}

bool
ANN::Sink_log::open(Size lengths, Size sizes)
{
  return true;
}

bool
ANN::Sink_log::feed(size_t which_, const Loc &where_, const Term &in,
                    const char *label_)
{
  label.set_label(label_ ? label_ : "",lab_len);
  log->log(in,label.label(),which_,&where_);
  return true;
}

bool
ANN::Sink_log::close()
{
  return true;
}
